.. _mountainMask:

Partially Hidden credits
-----------------------------------

.. raw:: html

        <center>
        <object><param name="movie"
        value="http://www.youtube.com/v/NsTgBah6Ebk&hl=en_US&fs=1&rel=0">
        </param><param name="allowFullScreen" value="true"></param><param
        name="allowscriptaccess" value="always"></param><embed
        src="http://www.youtube.com/v/NsTgBah6Ebk&hl=en_US&fs=1&rel=0"
        type="application/x-shockwave-flash" allowscriptaccess="always"
        allowfullscreen="true" width="550" height="450"></embed></object>
        </center>

First, see in :ref:`autocredits` how to make credits automatically with MoviePy. Before seeing the code for this video, here is a tutorial video that explains the different steps (also made with MoviePy):
 
.. raw:: html

        <center>
        <object><param name="movie"
        value="http://www.youtube.com/v/7tKABfc0Yzw&hl=en_US&fs=1&rel=0">
        </param><param name="allowFullScreen" value="true"></param><param
        name="allowscriptaccess" value="always"></param><embed
        src="http://www.youtube.com/v/7tKABfc0Yzw&hl=en_US&fs=1&rel=0"
        type="application/x-shockwave-flash" allowscriptaccess="always"
        allowfullscreen="true" width="550" height="450"></embed></object>
        </center>





And here is the code:

.. literalinclude:: ../../examples/masked_credits.py
